@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -24,6 +24,7 @@
 
 #include <glib-object.h>
 #include "gpm-graph-widget.h"
+#include "gpm-engine.h"
 
 G_BEGIN_DECLS
 
@@ -80,30 +81,34 @@ GQuark		 gpm_info_error_quark			(void);
 
 void		 gpm_info_show_window			(GpmInfo	*info);
 void		 gpm_info_event_log			(GpmInfo	*info,
-							 GpmGraphWidgetEvent	 event,
+							 GpmGraphWidgetEvent event,
 							 const gchar	*desc);
 
-gboolean	 gpm_statistics_get_types		(GpmInfo	*info,
+gboolean	 gpm_statistics_get_data_types		(GpmInfo	*info,
 							 gchar		***types,
 							 GError		**error);
 gboolean	 gpm_statistics_get_event_log		(GpmInfo	*info,
-							 gint 	    	 seconds,
 							 GPtrArray	**array,
 							 GError		**error);
 gboolean	 gpm_statistics_get_data		(GpmInfo	*info,
-							 gint 	    	 seconds,
 							 const gchar	*type,
 							 GPtrArray	**array,
 							 GError		**error);
-gboolean	 gpm_statistics_get_axis_type		(GpmInfo	*info,
+gboolean	 gpm_statistics_get_parameters		(GpmInfo	*info,
 							 gchar		*type,
 							 gchar		**axis_type_x,
 							 gchar		**axis_type_y,
+							 gchar		**axis_desc_x,
+							 gchar		**axis_desc_y,
+							 GPtrArray	**key_data,
+							 GPtrArray	**key_event,
 							 GError		**error);
 void		 gpm_info_explain_reason		(GpmInfo	*info,
 							 GpmGraphWidgetEvent event,
 							 const gchar	*pre,
 							 const gchar	*post);
+gboolean	 gpm_info_set_collection_data		(GpmInfo	*info,
+							 GpmEngineCollection *collection);
 
 G_END_DECLS
 
