@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Taken in part from:
  *  - lshal   (C) 2003 David Zeuthen, <david@fubar.dk>
@@ -33,14 +33,14 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
+#include <gst/gst.h>
 
 #include "gpm-stock-icons.h"
-#include "gpm-hal.h"
 #include "gpm-common.h"
 #include "gpm-debug.h"
 
 #include "gpm-manager.h"
-#include "dbus/gpm-dbus-manager.h"
+#include "dbus/xdg-power-management-core.h"
 
 static void gpm_exit (GpmManager *manager);
 
@@ -93,6 +93,7 @@ gpm_object_register (DBusGConnection *connection,
 	}
 
 	dbus_g_object_type_install_info (GPM_TYPE_MANAGER, &dbus_glib_gpm_manager_object_info);
+	dbus_g_error_domain_register (GPM_MANAGER_ERROR, NULL, GPM_MANAGER_TYPE_ERROR);
 	dbus_g_connection_register_g_object (connection, GPM_DBUS_PATH, object);
 
 	return TRUE;
@@ -139,6 +140,7 @@ main (int argc, char *argv[])
 	gboolean verbose = FALSE;
 	gboolean no_daemon = FALSE;
 	gboolean timed_exit = FALSE;
+	gboolean immediate_exit = FALSE;
 	GpmManager *manager = NULL;
 	GError *error = NULL;
 	GOptionContext *context;
@@ -153,6 +155,8 @@ main (int argc, char *argv[])
 		  N_("Show extra debugging information"), NULL },
 		{ "timed-exit", '\0', 0, G_OPTION_ARG_NONE, &timed_exit,
 		  N_("Exit after a small delay (for debugging)"), NULL },
+		{ "immediate-exit", '\0', 0, G_OPTION_ARG_NONE, &immediate_exit,
+		  N_("Exit after a the manager has loaded (for debugging)"), NULL },
 		{ "debug", '\0', 0, G_OPTION_ARG_STRING_ARRAY, &debugoptions,
 		  N_("Debug specific files, e.g. power"), NULL },
 		{ NULL}
@@ -193,44 +197,46 @@ main (int argc, char *argv[])
 	/* Add all of the options specified on the --debug line */
 	if (debugoptions) {
 		for (i = 0; debugoptions[i]; i++) {
-			gpm_add_debug_option (debugoptions[i]);
+			gpm_debug_add_option (debugoptions[i]);
 		}
 	}
 
 	/* we need to daemonize before we get a system connection to fix #366057 */
-	if (! no_daemon && daemon (0, 0)) {
-		gpm_critical_error ("Could not daemonize: %s", g_strerror (errno));
+	if (no_daemon == FALSE && daemon (0, 0)) {
+		gpm_error ("Could not daemonize: %s", g_strerror (errno));
 	}
 
+	gpm_debug ("GNOME %s %s", GPM_NAME, VERSION);
+
 	/* check dbus connections, exit if not valid */
 	system_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
 	if (error) {
 		gpm_warning ("%s", error->message);
 		g_error_free (error);
-		gpm_critical_error ("This program cannot start until you start "
-				    "the dbus system service.\n"
-				    "It is <b>strongly recommended</b> you reboot "
-				    "your computer after starting this service.");
-		/* abort at this point */
-		exit (1);
+		gpm_error ("This program cannot start until you start "
+			   "the dbus system service.\n"
+			   "It is <b>strongly recommended</b> you reboot "
+			   "your computer after starting this service.");
 	}
 
 	session_connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (error) {
 		gpm_warning ("%s", error->message);
 		g_error_free (error);
-		gpm_critical_error ("This program cannot start until you start the "
-				    "dbus session service.\n\n"
-				    "This is usually started automatically in X "
-				    "or gnome startup when you start a new session.");
-		/* abort at this point */
-		exit (1);
+		gpm_error ("This program cannot start until you start the "
+			   "dbus session service.\n\n"
+			   "This is usually started automatically in X "
+			   "or gnome startup when you start a new session.");
 	}
 
-	if (! gpm_stock_icons_init()) {
-		gpm_critical_error ("Cannot continue without stock icons");
+	if (gpm_stock_icons_init() == FALSE) {
+		gpm_error ("Cannot continue without stock icons");
 	}
 
+	/* initialise gstreamer */
+	gst_init (&argc, &argv);
+
+	/* create a new gui object */
 	manager = gpm_manager_new ();
 
 	if (!gpm_object_register (session_connection, G_OBJECT (manager))) {
@@ -242,11 +248,13 @@ main (int argc, char *argv[])
 
 	/* Only timeout and close the mainloop if we have specified it
 	 * on the command line */
-	if (timed_exit) {
+	if (timed_exit == TRUE) {
 		g_timeout_add (1000 * 20, (GSourceFunc) timed_exit_cb, loop);
 	}
 
-	g_main_loop_run (loop);
+	if (immediate_exit == FALSE) {
+		g_main_loop_run (loop);
+	}
 
 	gpm_stock_icons_shutdown ();
 	gpm_debug_shutdown ();
