@@ -122,7 +122,46 @@ gpm_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* NONE:STRING,STRING,STRING (gpm-marshal.list:3) */
+/* NONE:UINT,STRING,STRING (gpm-marshal.list:3) */
+void
+gpm_marshal_VOID__UINT_STRING_STRING (GClosure     *closure,
+                                      GValue       *return_value,
+                                      guint         n_param_values,
+                                      const GValue *param_values,
+                                      gpointer      invocation_hint,
+                                      gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_STRING_STRING) (gpointer     data1,
+                                                         guint        arg_1,
+                                                         gpointer     arg_2,
+                                                         gpointer     arg_3,
+                                                         gpointer     data2);
+  register GMarshalFunc_VOID__UINT_STRING_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_string (param_values + 3),
+            data2);
+}
+
+/* NONE:STRING,STRING,STRING (gpm-marshal.list:4) */
 void
 gpm_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                         GValue       *return_value,
@@ -161,7 +200,7 @@ gpm_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* NONE:STRING,BOOLEAN (gpm-marshal.list:4) */
+/* NONE:STRING,BOOLEAN (gpm-marshal.list:5) */
 void
 gpm_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                   GValue       *return_value,
@@ -198,7 +237,7 @@ gpm_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:STRING,STRING,BOOLEAN (gpm-marshal.list:5) */
+/* NONE:STRING,STRING,BOOLEAN (gpm-marshal.list:6) */
 void
 gpm_marshal_VOID__STRING_STRING_BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
@@ -237,7 +276,7 @@ gpm_marshal_VOID__STRING_STRING_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:STRING,STRING,BOOLEAN,BOOLEAN,BOOLEAN (gpm-marshal.list:6) */
+/* NONE:STRING,STRING,BOOLEAN,BOOLEAN,BOOLEAN (gpm-marshal.list:7) */
 void
 gpm_marshal_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
@@ -280,11 +319,11 @@ gpm_marshal_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:INT (gpm-marshal.list:7) */
+/* NONE:INT (gpm-marshal.list:8) */
 
-/* NONE:STRING (gpm-marshal.list:8) */
+/* NONE:STRING (gpm-marshal.list:9) */
 
-/* NONE:INT,LONG,BOOLEAN,BOOLEAN (gpm-marshal.list:9) */
+/* NONE:INT,LONG,BOOLEAN,BOOLEAN (gpm-marshal.list:10) */
 void
 gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
@@ -325,3 +364,81 @@ gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
+/* NONE:BOOLEAN,BOOLEAN (gpm-marshal.list:11) */
+void
+gpm_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (gpointer     data1,
+                                                      gboolean     arg_1,
+                                                      gboolean     arg_2,
+                                                      gpointer     data2);
+  register GMarshalFunc_VOID__BOOLEAN_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_boolean (param_values + 1),
+            g_marshal_value_peek_boolean (param_values + 2),
+            data2);
+}
+
+/* NONE:UINT (gpm-marshal.list:12) */
+
+/* NONE:UINT,UINT (gpm-marshal.list:13) */
+void
+gpm_marshal_VOID__UINT_UINT (GClosure     *closure,
+                             GValue       *return_value,
+                             guint         n_param_values,
+                             const GValue *param_values,
+                             gpointer      invocation_hint,
+                             gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
+                                                guint        arg_1,
+                                                guint        arg_2,
+                                                gpointer     data2);
+  register GMarshalFunc_VOID__UINT_UINT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_UINT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 2),
+            data2);
+}
+
+/* NONE:UINT,POINTER (gpm-marshal.list:14) */
+
