@@ -35,9 +35,9 @@
 
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
+#include <libdbus-proxy.h>
 
-#include <libgpm.h>
-
+#include "gpm-common.h"
 #include "gpm-ac-adapter.h"
 #include "gpm-array.h"
 #include "gpm-array-float.h"
@@ -177,6 +177,34 @@ gpm_profile_get_data_time_percent (GpmProfile *profile, gboolean discharge)
 	return profile->priv->present_array_data;
 }
 
+/**
+ * gpm_profile_get_accuracy_average:
+ *
+ * @profile: This class
+ *
+ * Gets the average value of the accuracy, i.e. whether this discharge profile
+ * is to be trusted. We have the situation where if a user repeatedly charges
+ * from 30% to 100% and then from 100% to 30% then g-p-m assumes that <30%
+ * is impossible and uses the 30% as the lowest point of the integral.
+ * Working out the average gives us a good ballpart for the system.
+ * Generally, a 40%+ average is good enough for a policy decision.
+ * (use GPM_PROFILE_GOOD_TRUST for value)
+ */
+gfloat
+gpm_profile_get_accuracy_average (GpmProfile *profile, gboolean discharge)
+{
+	GArray *array;
+
+	/* get the correct data */
+	if (discharge == TRUE) {
+		array = profile->priv->float_accuracy_discharge;
+	} else {
+		array = profile->priv->float_accuracy_charge;
+	}
+
+	return gpm_array_float_get_average (array);
+}
+
 /**
  * gpm_profile_get_data_accuracy_percent:
  *
@@ -549,7 +577,7 @@ gpm_profile_load_data (GpmProfile *profile, gboolean discharge)
 
 		/* directory might not exist */
 		path = g_build_filename (g_get_home_dir (), ".gnome2", "gnome-power-manager", NULL);
-		g_mkdir_with_parents (path, 744);
+		g_mkdir_with_parents (path, 0770);
 		g_free (path);
 
 		gpm_debug ("no data found, generating initial (poor) data");
