@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -29,7 +29,7 @@
 #include "gpm-conf.h"
 #include "gpm-screensaver.h"
 #include "gpm-debug.h"
-#include "gpm-proxy.h"
+#include <libdbus-proxy.h>
 
 static void     gpm_screensaver_class_init (GpmScreensaverClass *klass);
 static void     gpm_screensaver_init       (GpmScreensaver      *screensaver);
@@ -37,17 +37,9 @@ static void     gpm_screensaver_finalize   (GObject		*object);
 
 #define GPM_SCREENSAVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_SCREENSAVER, GpmScreensaverPrivate))
 
-#define GS_LISTENER_SERVICE	"org.gnome.ScreenSaver"
-#define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
-#define GS_LISTENER_INTERFACE	"org.gnome.ScreenSaver"
-
-#define GS_PREF_DIR		"/apps/gnome-screensaver"
-#define GS_PREF_LOCK_ENABLED	GS_PREF_DIR "/lock_enabled"
-#define GS_PREF_IDLE_DELAY	GS_PREF_DIR "/idle_delay"
-
 struct GpmScreensaverPrivate
 {
-	GpmProxy		*gproxy;
+	DbusProxy		*gproxy;
 	GpmConf			*conf;
 	guint			 idle_delay;	/* the setting in g-s-p, cached */
 };
@@ -55,12 +47,14 @@ struct GpmScreensaverPrivate
 enum {
 	GS_DELAY_CHANGED,
 	CONNECTION_CHANGED,
-	IDLE_CHANGED,
+	SESSION_IDLE_CHANGED,
+	POWERSAVE_IDLE_CHANGED,
 	AUTH_REQUEST,
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0, };
+static gpointer gpm_screensaver_object = NULL;
 
 G_DEFINE_TYPE (GpmScreensaver, gpm_screensaver, G_TYPE_OBJECT)
 
@@ -90,12 +84,23 @@ gpm_screensaver_auth_end (DBusGProxy     *proxy,
  *  has entered a valid password or re-authenticated.
  */
 static void
-gpm_screensaver_idle_changed (DBusGProxy     *proxy,
+gpm_screensaver_session_idle_changed (DBusGProxy     *proxy,
 			      gboolean        is_idle,
 			      GpmScreensaver *screensaver)
 {
-	gpm_debug ("emitting idle-changed : (%i)", is_idle);
-	g_signal_emit (screensaver, signals [IDLE_CHANGED], 0, is_idle);
+	gpm_debug ("emitting session-idle-changed : (%i)", is_idle);
+	g_signal_emit (screensaver, signals [SESSION_IDLE_CHANGED], 0, is_idle);
+}
+
+/** Invoked after a short delay
+ */
+static void
+gpm_screensaver_powersave_idle_changed (DBusGProxy     *proxy,
+			                gboolean        is_idle,
+			                GpmScreensaver *screensaver)
+{
+	gpm_debug ("emitting powersave-idle-changed : (%i)", is_idle);
+	g_signal_emit (screensaver, signals [POWERSAVE_IDLE_CHANGED], 0, is_idle);
 }
 
 /**
@@ -109,11 +114,11 @@ gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	g_signal_emit (screensaver, signals [CONNECTION_CHANGED], 0, TRUE);
 
@@ -135,7 +140,14 @@ gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
 	dbus_g_proxy_add_signal (proxy, "SessionIdleChanged", G_TYPE_BOOLEAN, G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal (proxy,
 				     "SessionIdleChanged",
-				     G_CALLBACK (gpm_screensaver_idle_changed),
+				     G_CALLBACK (gpm_screensaver_session_idle_changed),
+				     screensaver, NULL);
+
+	/* get SessionIdleChanged */
+	dbus_g_proxy_add_signal (proxy, "SessionPowerManagementIdleChanged", G_TYPE_BOOLEAN, G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (proxy,
+				     "SessionPowerManagementIdleChanged",
+				     G_CALLBACK (gpm_screensaver_powersave_idle_changed),
 				     screensaver, NULL);
 
 	return TRUE;
@@ -228,11 +240,11 @@ gpm_screensaver_lock (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	gpm_debug ("doing gnome-screensaver lock");
 	dbus_g_proxy_call_no_reply (proxy, "Lock", G_TYPE_INVALID);
@@ -274,11 +286,11 @@ gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 	g_return_val_if_fail (reason != NULL, 0);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	/* shouldn't be, but make sure proxy valid */
 	if (proxy == NULL) {
@@ -316,11 +328,11 @@ gpm_screensaver_remove_throttle (GpmScreensaver *screensaver,
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	gpm_debug ("removing throttle: id %u", cookie);
 	ret = dbus_g_proxy_call (proxy, "UnThrottle", &error,
@@ -355,11 +367,11 @@ gpm_screensaver_check_running (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	ret = dbus_g_proxy_call (proxy, "GetActive", &error,
 				 G_TYPE_INVALID,
@@ -388,11 +400,11 @@ gpm_screensaver_poke (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	gpm_debug ("poke");
 	dbus_g_proxy_call_no_reply (proxy,
@@ -417,11 +429,11 @@ gpm_screensaver_get_idle (GpmScreensaver *screensaver, gint *time_secs)
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 	g_return_val_if_fail (time != NULL, FALSE);
 
-	proxy = gpm_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
 		return FALSE;
-	}	
+	}
 
 	ret = dbus_g_proxy_call (proxy, "GetActiveTime", &error,
 				 G_TYPE_INVALID,
@@ -481,11 +493,20 @@ gpm_screensaver_class_init (GpmScreensaverClass *klass)
 			      g_cclosure_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 
-	signals [IDLE_CHANGED] =
-		g_signal_new ("idle-changed",
+	signals [SESSION_IDLE_CHANGED] =
+		g_signal_new ("session-idle-changed",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, idle_changed),
+			      G_STRUCT_OFFSET (GpmScreensaverClass, session_idle_changed),
+			      NULL,
+			      NULL,
+			      g_cclosure_marshal_VOID__BOOLEAN,
+			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
+	signals [POWERSAVE_IDLE_CHANGED] =
+		g_signal_new ("powersave-idle-changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmScreensaverClass, session_idle_changed),
 			      NULL,
 			      NULL,
 			      g_cclosure_marshal_VOID__BOOLEAN,
@@ -523,9 +544,9 @@ gpm_screensaver_init (GpmScreensaver *screensaver)
 
 	screensaver->priv = GPM_SCREENSAVER_GET_PRIVATE (screensaver);
 
-	screensaver->priv->gproxy = gpm_proxy_new ();
-	proxy = gpm_proxy_assign (screensaver->priv->gproxy,
-				  GPM_PROXY_SESSION,
+	screensaver->priv->gproxy = dbus_proxy_new ();
+	proxy = dbus_proxy_assign (screensaver->priv->gproxy,
+				  DBUS_PROXY_SESSION,
 				  GS_LISTENER_SERVICE,
 				  GS_LISTENER_PATH,
 				  GS_LISTENER_INTERFACE);
@@ -573,7 +594,11 @@ gpm_screensaver_finalize (GObject *object)
 GpmScreensaver *
 gpm_screensaver_new (void)
 {
-	GpmScreensaver *screensaver;
-	screensaver = g_object_new (GPM_TYPE_SCREENSAVER, NULL);
-	return GPM_SCREENSAVER (screensaver);
+	if (gpm_screensaver_object != NULL) {
+		g_object_ref (gpm_screensaver_object);
+	} else {
+		gpm_screensaver_object = g_object_new (GPM_TYPE_SCREENSAVER, NULL);
+		g_object_add_weak_pointer (gpm_screensaver_object, &gpm_screensaver_object);
+	}
+	return GPM_SCREENSAVER (gpm_screensaver_object);
 }
